@@ -86,7 +86,7 @@ def update_config(run_id: int, config_item_dict: list):
     rsp: UpdateConfigResponse = get_stub().update_config(UpdateConfigRequest(
         runId=run_id,
         item=item,
-        authorization=http_interface.get_jwt_key(),
+        authorization=f"Bearer {http_interface.get_jwt_key()}",
     ))
 
     return rsp.rsp_result.result == "success"
@@ -130,7 +130,7 @@ def upload_log(run_id: int, log_step: int, item_dict: Dict[str, Union[int, str,
         item=item,
         step=LogStep(num=log_step),
         run=RunInfo(run_id=run_id),
-        authorization=http_interface.get_jwt_key(),
+        authorization=f"Bearer {http_interface.get_jwt_key()}",
     ))
     return rsp.rsp_result.result == "success"
 
@@ -161,7 +161,7 @@ def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_
         artifactType=artifact_type,
         digest=entry_digest,
         last_file_yn=last_file_yn,
-        authorization=http_interface.get_jwt_key(),
+        authorization=f"Bearer {http_interface.get_jwt_key()}",
         teamName=team_name,
         expName=exp_name,
         runName=run_name,
@@ -193,7 +193,7 @@ def load_file(upload_type: str, local_path: str, root_path: str, path: str, run_
                 artifactType=artifact_type,
                 digest=entry_digest,
                 last_file_yn=last_file_yn,
-                authorization=http_interface.get_jwt_key(),
+                authorization=f"Bearer {http_interface.get_jwt_key()}",
                 teamName=team_name,
                 expName=exp_name,
                 runName=run_name,
@@ -246,7 +246,7 @@ def download_file(path: str, artifact_id: int, local_path: str, team_name: str,
     save_file(local_path, file_index, total_file_count, file_size, get_stub().download_file(DownloadFileRequest(
         path=path,
         artifact_id=artifact_id,
-        authorization=http_interface.get_jwt_key(),
+        authorization=f"Bearer {http_interface.get_jwt_key()}",
         teamName=team_name,
         expName=exp_name,
         artifactName=artifact_name,
@@ -287,13 +287,13 @@ def upload_artifact(run_id: int, artifact: Artifact, artifact_digest: str, teamN
             expName=expName,
             artifact_entry=entry_list,
         ),
-        authorization=http_interface.get_jwt_key(),
+        authorization=f"Bearer {http_interface.get_jwt_key()}",
     ))
     return rsp.artifact_id if rsp.rsp_result.result == "success" else None
 
 
-def use_artifact(name: str, type: str, tag: str, team_name: str, exp_name: str, run_id: int) -> Tuple(int,
-                                                                                                      ArtifactRecord):
+def use_artifact(name: str, type: str, tag: str, team_name: str, exp_name: str, run_id: int) -> Tuple[int,
+                                                                                                      ArtifactRecord]:
     logger.debug(f"""
         use_artifact(): ( 
             "artifact_name":"{name}",
@@ -302,7 +302,7 @@ def use_artifact(name: str, type: str, tag: str, team_name: str, exp_name: str,
             "team_name":"{team_name}",
             "exp_name":"{exp_name}",
             "run_id":"{run_id}",
-            "authorization":"{http_interface.get_jwt_key()}"
+            "authorization": "Bearer {http_interface.get_jwt_key()}"
         )""")
 
     try:
@@ -313,7 +313,7 @@ def use_artifact(name: str, type: str, tag: str, team_name: str, exp_name: str,
             team_name=team_name,
             exp_name=exp_name,
             run_id=run_id,
-            authorization=http_interface.get_jwt_key(),
+            authorization=f"Bearer {http_interface.get_jwt_key()}",
         ))
     except grpc.RpcError as e:
         logger.exception("Network Error")
